@@ -7,7 +7,7 @@ require Exporter;
 @EXPORT = qw(expand unexpand $tabstop);
 
 use vars qw($VERSION $SUBVERSION $tabstop $debug);
-$VERSION = 2012.0815;
+$VERSION = 2013.0426;
 $SUBVERSION = 'modern';
 
 use strict;
@@ -126,6 +126,27 @@ in each line for both expansion and unexpansion.  These are overstrike
 characters that do not increment the logical position.  Make sure
 you have the appropriate Unicode settings enabled.
 
+=head1 EXPORTS
+
+The following are exported:
+
+=over 4
+
+=item expand
+
+=item unexpand
+
+=item $tabstop
+
+The C<$tabstop> variable controls how many column positions apart each
+tabstop is.  The default is 8.
+
+Please note that C<local($tabstop)> doesn't do the right thing and if you want
+to use C<local> to override C<$tabstop>, you need to use
+C<local($Text::Tabs::tabstop)>.
+
+=back
+
 =head1 EXAMPLE
 
   #!perl
@@ -165,7 +186,8 @@ or otherwise deal with any other zero-, half-, and full-width characters.
 
 Copyright (C) 1996-2002,2005,2006 David Muir Sharnoff.  
 Copyright (C) 2005 Aristotle Pagaltzis 
-Copyright (C) 2012 Google, Inc.
+Copyright (C) 2012-2013 Google, Inc.
 This module may be modified, used, copied, and redistributed at your own risk.
-Publicly redistributed modified versions must use a different name.
-
+Although allowed by the preceding license, please do not publicly
+redistribute modified versions of this code with the name "Text::Tabs"
+unless it passes the unmodified Text::Tabs test suite.
